@@ -69,7 +69,7 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelper):
     @_logger.call
     def collect(self, sender: Any, document: TextDocument, range: Range) -> Optional[List[InlayHint]]:
         config = self.get_config(document)
-        if config is None or not config.parameter_names and not config.namespaces:
+        if config is None or (not config.parameter_names and not config.namespaces):
             return None
 
         model = self.parent.documents_cache.get_model(document, False)
@@ -107,13 +107,13 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelper):
             keyword_token,
             arguments,
             namespace,
-            range_from_token(keyword_token).start,
+            range_from_token(keyword_token).end,
         )
 
         if kw_result is None:
             return None
 
-        kw_doc, _ = kw_result
+        kw_doc, keyword_token = kw_result
 
         if kw_doc is None:
             return None
